summaryrefslogtreecommitdiff
path: root/include/hashcomp.h
diff options
context:
space:
mode:
authorbrain <brain@e03df62e-2008-0410-955e-edbf42e46eb7>2006-08-01 10:37:16 +0000
committerbrain <brain@e03df62e-2008-0410-955e-edbf42e46eb7>2006-08-01 10:37:16 +0000
commitc80508b28be5947648f59710e6653f793a73bd76 (patch)
tree87c3c9509ba2ae20312604d13ee14abcbea8b948 /include/hashcomp.h
parent15a3422e9ef297a6867d3c00b1d46079399739c7 (diff)
Move to entirely using insp_sockaddr and insp_inaddr for socket stuff, first step on the road to ipv6 support
git-svn-id: http://svn.inspircd.org/repository/trunk/inspircd@4609 e03df62e-2008-0410-955e-edbf42e46eb7
Diffstat (limited to 'include/hashcomp.h')
-rw-r--r--include/hashcomp.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/include/hashcomp.h b/include/hashcomp.h
index 1d3a5d0b1..714d3286f 100644
--- a/include/hashcomp.h
+++ b/include/hashcomp.h
@@ -40,9 +40,9 @@ using namespace std;
namespace nspace
{
- template<> struct hash<in_addr>
+ template<> struct hash<insp_inaddr>
{
- size_t operator()(const struct in_addr &a) const;
+ size_t operator()(const insp_inaddr &a) const;
};
template<> struct hash<std::string>
@@ -68,7 +68,7 @@ namespace irc
};
/** This class returns true if two in_addr structs match.
* Checking is done by copying both into a size_t then doing a
* numeric comparison of the two.
*/
@@ -76,7 +76,7 @@ namespace irc
{
/** The operator () does the actual comparison in hash_map
*/
- bool operator()(const in_addr &s1, const in_addr &s2) const;
+ bool operator()(const insp_inaddr &s1, const insp_inaddr &s2) const;
};
/** irc::tokenstream reads a string formatted as per RFC1459 and RFC2812.
@@ -68,7 +68,7 @@ namespace irc
};
- /** This class returns true if two in_addr structs match.
+ /** This class returns true if two insp_inaddr structs match.
* Checking is done by copying both into a size_t then doing a
* numeric comparison of the two.